<template>
  <div class="case-handling-status">
    <public-title title="案件办理方式">
      <template v-slot:title-end>
        <van-icon name="search" size="19" color="#5e9df0" @click="showPopup('querySearchPopup')" />
      </template>
    </public-title>
    <div class="chart-container">
      <div id="case-handling-status-chart" style="width: 100%;height: 100%;" />
    </div>

    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="queryParams"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {
  statisticsCaseHandleSituation as echartsInterface
} from '@/api/Mobile/leadershipKanban'
import PublicTitle from '../PublicTitle/index.vue'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

export default {
  name: 'CaseHandlingStatus', // 案件办理方式
  components: {QuerySearchPopup, PublicTitle},
  data() {
    return {
      queryParams: {
        dateTime: ''
      },
      myChart: null,  // 图表实例对象
      chartData: {},
      querySearchPopup: false
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('case-handling-status-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      this.chartData = await echartsInterface(this.queryParams)
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        color: ['#3eadfd', '#ff6e79', '#ffda68'],
        graphic: [{
          type: 'group',
          left: '50%',
          top: '57%',
          bounding: 'raw',
          children: [{
            type: 'text',
            style: {
              text: `案件总数\n${this.chartData?.total || 0}`,
              fontSize: 11,
              lineHeight: 16,
              fill: '#36d9c6',
              textVerticalAlign: 'middle',
              textAlign: 'center'
            }
          }]
        }],
        tooltip: {
          trigger: 'item',
          textStyle: {
            fontSize: 10,
            color: '#606266'
          }
        },
        legend: {
          position: 'center',
          top: 0,
          textStyle: {
            fontSize: 10,
            color: '#606266'
          }
        },
        series: [
          {
            name: '案件处理状态',
            type: 'pie',
            startAngle: 90,
            radius: ['48%', '80%'],
            center: ['50%', '55%'],
            selectedMode: 'single',
            selectedOffset: 10,
            clockwise: true,
            itemStyle: {
              borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.directProcessing || 0,
                name: '直接处理'
              },
              {
                value: this.chartData?.dratf || 0,
                name: '上报'
              },
              {
                value: this.chartData?.report || 0,
                name: '草稿'
              }
            ],
            label: {
              normal: {
                show: true,
                position: 'inside',
                formatter: ({percent}) => percent ? percent.toFixed(0) + '%' : '',
                textStyle: {
                  align: 'center',
                  fontSize: 11,
                  fontWeight: 'bolder',
                  color: '#fff'
                }
              }
            }
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    },

    // 查询/重置按钮点击
    searchData() {
      this.getChartData()
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.case-handling-status {
  width: 100%;
  min-height: 260PX;
  display: flex;
  flex-direction: column;
  box-shadow: 0 10px 15px 0 rgba(0, 0, 0, 0.1), 0 10px 25px 0 rgba(0, 0, 0, 0.1);
  border-radius: 40px;


  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 40px 0 60px;
  }
}
</style>
